package com.dzeio.openhealth.ui.steps

import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.core.widget.NestedScrollView
import androidx.recyclerview.widget.LinearLayoutManager
import com.dzeio.charts.Entry
import com.dzeio.openhealth.Application
import com.dzeio.openhealth.R
import com.dzeio.openhealth.adapters.StepsAdapter
import com.dzeio.openhealth.core.BaseFragment
import com.dzeio.openhealth.databinding.FragmentStepsHomeBinding
import com.google.android.material.color.MaterialColors
import dagger.hilt.android.AndroidEntryPoint
import java.text.DateFormat
import java.util.Date
import java.util.Locale

@AndroidEntryPoint
class StepsHomeFragment :
    BaseFragment<StepsHomeViewModel, FragmentStepsHomeBinding>(StepsHomeViewModel::class.java) {

    companion object {
        const val TAG = "${Application.TAG}/SHFragment"
    }

    override val bindingInflater: (LayoutInflater, ViewGroup?, Boolean) -> FragmentStepsHomeBinding =
        FragmentStepsHomeBinding::inflate

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        viewModel.init()

        val recycler = binding.list

        val manager = LinearLayoutManager(requireContext())
        recycler.layoutManager = manager

        val adapter = StepsAdapter()
        adapter.onItemClick = {
//            findNavController().navigate(
//                WaterHomeFragmentDirections.actionNavWaterHomeToNavWaterEdit(
//                    it.id
//                )
//            )
        }
        recycler.adapter = adapter

        val chart = binding.chart

        viewModel.items.observe(viewLifecycleOwner) { list ->
            adapter.set(list)
            chart.xAxis.entriesDisplayed = 30
            chart.numberOfLabels = 2

//            chart.animation.enabled = false
            chart.animation.refreshRate = 60
            chart.animation.duration = 500

            chart.xAxis.labels.color = MaterialColors.getColor(
                requireView(),
                com.google.android.material.R.attr.colorOnBackground
            )
            chart.xAxis.labels.size = 32f
            chart.yAxis.color = MaterialColors.getColor(
                requireView(),
                com.google.android.material.R.attr.colorPrimary
            )

            chart.list = list.reversed().map {
                return@map Entry(it.timestamp.toDouble(), it.value.toFloat())
            } as ArrayList<Entry>

            chart.xAxis.onValueFormat = onValueFormat@{
                val formatter = DateFormat.getDateTimeInstance(
                    DateFormat.SHORT,
                    DateFormat.SHORT,
                    Locale.getDefault()
                )
                return@onValueFormat formatter.format(Date(it.toLong()))
            }

//            chart.yAxis.max = (total / list.size).toInt()

            chart.refresh()
        }

        val scrollView = requireActivity().findViewById<NestedScrollView>(R.id.scrollView)
        var scrollEnabled = false
        scrollView.setOnTouchListener { view, _ ->
            view.performClick()
            if (scrollEnabled) {
            } else {
                return@setOnTouchListener !scrollEnabled
            }
            return@setOnTouchListener true
        }

        binding.chart.setOnToggleScroll {
            Log.d(TAG, it.toString())
            scrollEnabled = it
        }
    }
}
